tlslite.utils.python_rc4.Python_RC4

Package tlslite :: Package utils :: Module python_rc4 :: Class Python_RC4 |
[hide private]
[frames] | no frames]

# Class Python_RC4

source code

    rc4.RC4 --+
              |
             Python_RC4

Instance Methods | [hide private]
__init__(self, keyBytes) | source code
decrypt(self, ciphertext) | source code
encrypt(self, plaintextBytes) | source code

Method Details | [hide private]

### __init__(self, keyBytes) (Constructor) | source code
Overrides: rc4.RC4.__init__

### decrypt(self, ciphertext) | source code
Overrides: rc4.RC4.decrypt

### encrypt(self, plaintextBytes) | source code
Overrides: rc4.RC4.encrypt